@@ -1,10 +1,7 @@
 #' GitHub board (legacy API)
 #'
-#' To use a GitHub board, you'll need to set up authentication. This is likely
-#' to just work if you already use GitHub for other purposes since pins will
-#' inspect your  `GITHUB_PAT` environment variable. Otherwise, you can follow
-#' the instructions at <https://happygitwithr.com/credential-caching.html> to
-#' get set up.
+#' To use a GitHub board, you'll need to set up authentication, following
+#' the instructions at <https://happygitwithr.com/https-pat.html#https-pat>.
 #'
 #' # Large Files
 #'
@@ -21,8 +18,8 @@
 #' @param repo The GitHub repository formatted as 'owner/repo'.
 #' @param branch The branch to use to commit pins. Default, `NULL`, will
 #'   use `main` or `master` if present.
-#' @param token GitHub personal acess token. Defaults to env var `GITHUB_PAT`
-#'   if not set.
+#' @param token GitHub personal access token.
+#'   Uses [gitcreds](https://gitcreds.r-lib.org) if not set.
 #' @param path The subdirectory in the repo where the pins will be stored.
 #' @param host The URL of the GitHub API. You'll need to customise
 #'   this to use GitHub enterprise, e.g. `"https://yourhostname/api/v3"`.
@@ -39,10 +36,10 @@ legacy_github <- function(
                          path = "",
                          host = "https://api.github.com",
                          name = "github",
+                         cache = NULL,
                          ...) {
 
-  token <- token %||% envvar_get("GITHUB_PAT") %||%
-    abort("Specify GitHub PAT with `token` or 'GITHUB_PAT' env var")
+  cache <- cache %||% board_cache_path(name)
 
   board <- new_board_v0("pins_board_github",
     name = name,
@@ -50,6 +47,7 @@ legacy_github <- function(
     repo = repo,
     path = if (!is.null(path) && nchar(path) > 0) paste0(path, "/") else "",
     host = host,
+    cache = cache,
     ...
   )
 
@@ -97,7 +95,7 @@ board_register_github <- function(name = "github",
                                   token = NULL,
                                   path = "",
                                   host = "https://api.github.com",
-                                  cache = board_cache_path(name),
+                                  cache = NULL,
                                   ...) {
   board <- legacy_github(
     name = name,
@@ -116,7 +114,8 @@ github_auth <- function(board) {
   if (!is.null(board$token)) {
     board$token
   } else {
-    Sys.getenv("GITHUB_PAT")
+    check_installed("gitcreds")
+    gitcreds::gitcreds_get()$password
   }
 }
 
@@ -185,7 +184,7 @@ github_update_index <- function(board, path, commit, operation, name = NULL, met
 
   file_url <- github_url(board, branch = branch, "/contents/", board$path, "data.txt")
 
-  base64 <- jsonlite::base64_enc(index_file)
+  base64 <- base64enc_file(index_file)
   response <- httr::PUT(file_url,
     body = list(
       message = commit,
@@ -273,7 +272,7 @@ github_upload_content <- function(board, name, file, file_path, commit, sha, bra
   file_url <- github_url(board, branch = branch, "/contents/", board$path, name, "/", file)
   pin_log("uploading ", file_url)
 
-  base64 <- jsonlite::base64_enc(file_path)
+  base64 <- base64enc_file(file_path)
   response <- httr::PUT(file_url,
     body = list(
       message = commit,
@@ -296,7 +295,7 @@ github_upload_blob <- function(board, file, file_path, commit) {
   blob_url <- github_url(board, branch = NULL, "/git/blobs")
   pin_log("uploading ", file)
 
-  base64 <- jsonlite::base64_enc(file_path)
+  base64 <- base64enc_file(file_path)
   response <- httr::POST(blob_url,
     body = list(
       content = base64,
@@ -780,3 +779,8 @@ board_pin_versions.pins_board_github <- function(board, name, ...) {
     message = sapply(commits, function(e) e$commit$message)
   )
 }
+
+base64enc_file <- function(path) {
+  r <- readBin(path, raw(), file.size(path))
+  jsonlite::base64_enc(r)
+}
