@@ -16,6 +16,6 @@
 #' board %>% pin_list()
 pin_delete <- function(board, names, ...) {
   ellipsis::check_dots_used(...)
-  check_board(board, "pin_delete()", "pin_remove()")
+  check_board(board, "pin_delete", "pin_remove")
   UseMethod("pin_delete")
 }
